(** Electron-electron repulsion integrals *)

open Constants
open Util



module Zm = struct

  let name = "Electron repulsion integrals"

  open Zero_m_parameters

  let zero_m z =
    let expo_pq_inv = z.expo_p_inv +. z.expo_q_inv in
    assert (expo_pq_inv <> 0.);
    let exp_pq = 1. /. expo_pq_inv in
    let t =
      if z.norm_pq_sq > integrals_cutoff then
        z.norm_pq_sq *. exp_pq
        else 0.
    in
    let maxm = z.maxm in
    let result = boys_function ~maxm t in
    let rec aux accu k = function
      | 0 -> result.(k) <- result.(k) *. accu
      | l -> 
        begin
          result.(k) <- result.(k) *. accu;
          let new_accu = -. accu *. exp_pq in
          aux new_accu (k+1) (l-1)
        end
    in
    let f = two_over_sq_pi *. (sqrt exp_pq) in
    aux f 0 maxm;
    result

end

module M = TwoElectronIntegralsNonSeparable.Make(Zm) 
include M

